@@ -1231,7 +1231,7 @@ class Bot:
 
         botx_api_sticker = await method.execute(payload)
 
-        return botx_api_sticker.to_domain()
+        return botx_api_sticker.to_domain(pack_id=sticker_pack_id)
 
     async def delete_sticker(
         self,
@@ -1372,7 +1372,7 @@ class Bot:
 
         botx_api_sticker = await method.execute(payload)
 
-        return botx_api_sticker.to_domain()
+        return botx_api_sticker.to_domain(pack_id=sticker_pack_id)
 
     async def edit_sticker_pack(
         self,
